Package: dockViewR
Title: Layout Manager Widget for R and 'shiny' Apps
Version: 0.3.0
Authors@R: 
    c(
    person("David", "Granjon", , "dgranjon@ymail.com", role = c("aut", "cre")),
    person("Nelson", "Stevens", email = "nelson.stevens92@gmail.com", role = "aut"),
    person("Nicolas", "Bennett", email = "nicolas@cynkra.com", role = "aut"),
    person("mathuo", email = "github.mathuo@gmail.com", role = "cph"),
    person("cynkra GmbH", email = "mail@cynkra.com", role = "fnd")
    )
Description: Provides R bindings to the 'dockview' 'JavaScript' library <https://dockview.dev/>.
    Create fully customizable grid layouts (docks) in seconds to include in interactive R reports with R Markdown or 'Quarto' or 
    in 'shiny' apps <https://shiny.posit.co/>. In 'shiny' mode, modify docks by dynamically adding, removing or moving panels or 
    groups of panels from the server function. Choose among 8 stunning themes (dark and light),
    serialise the state of a dock to restore it later.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: htmlwidgets, htmltools, shiny
Suggests: knitr, rmarkdown, roxy.shinylive, shinytest2, testthat (>=
        3.0.0), visNetwork, quarto, thematic, listviewer, jsonlite,
        withr
URL: https://github.com/cynkra/dockViewR,
        https://cynkra.github.io/dockViewR/
BugReports: https://github.com/cynkra/dockViewR/issues
Config/testthat/edition: 3
Depends: R (>= 2.10)
VignetteBuilder: quarto
NeedsCompilation: no
Packaged: 2025-12-05 10:47:34 UTC; davidgranjon
Author: David Granjon [aut, cre],
  Nelson Stevens [aut],
  Nicolas Bennett [aut],
  mathuo [cph],
  cynkra GmbH [fnd]
Maintainer: David Granjon <dgranjon@ymail.com>
Repository: CRAN
Date/Publication: 2025-12-06 11:40:08 UTC
Built: R 4.6.0; ; 2026-04-26 16:43:27 UTC; unix
