# Generated by roxygen2: do not edit by hand

S3method(new_dock_view_plugin,add_tab)
S3method(new_dock_view_plugin,remove_tab)
export(add_panel)
export(default_add_tab_callback)
export(default_remove_tab_callback)
export(dockViewOutput)
export(dock_view)
export(dock_view_output)
export(dock_view_proxy)
export(get_active_group)
export(get_active_panel)
export(get_active_views)
export(get_dock)
export(get_grid)
export(get_groups)
export(get_groups_ids)
export(get_groups_panels)
export(get_panels)
export(get_panels_ids)
export(is_add_tab_plugin)
export(is_dock_view_plugin)
export(is_remove_tab_plugin)
export(move_group)
export(move_group2)
export(move_panel)
export(new_add_tab_plugin)
export(new_dock_view_plugin)
export(new_remove_tab_plugin)
export(panel)
export(remove_panel)
export(renderDockView)
export(render_dock_view)
export(restore_dock)
export(save_dock)
export(select_panel)
export(set_panel_title)
export(update_dock_view)
import(htmlwidgets)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,icon)
importFrom(stats,setNames)
